CkAppBarConfig class

Constructors

CkAppBarConfig({dynamic onBack()?, Icon? backIcon, Widget? backButton, BoxDecoration decoration()?, Color? backgroundColor, double? height, Color iconColor()?, Color titleColor()?, List<Widget>? actions, AlignmentGeometry? titleAlignment, AlignmentGeometry? leadingAlignment, AlignmentGeometry? actionAlignment, double? titleSpacing, Widget titleBuilder(String title)?, EdgeInsets? leadingPadding, EdgeInsets? actionsPadding})

Properties

actionAlignment AlignmentGeometry?
final
actions List<Widget>?
final
actionsPadding EdgeInsets?
final
backButton Widget?
final
backgroundColor Color?
final
backIcon Icon?
final
decoration BoxDecoration Function()?
final
getBack → dynamic Function()?
no setter
hashCode int
The hash code for this object.
no setterinherited
height double?
final
iconColor Color Function()?
final
leadingAlignment AlignmentGeometry?
final
leadingPadding EdgeInsets?
final
onBack → dynamic Function()?
()=> Get.back() or Navigator.pop(context) etc
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleAlignment AlignmentGeometry?
final
titleBuilder Widget Function(String title)?
final
titleColor Color Function()?
final
titleSpacing double?
final

Methods

copyWith({dynamic onBack()?, Icon? backIcon, Widget? backButton, BoxDecoration decoration()?, Color? backgroundColor, double? height, Color iconColor()?, Color titleColor()?, List<Widget>? actions, AlignmentGeometry? titleAlignment, AlignmentGeometry? leadingAlignment, AlignmentGeometry? actionAlignment, double? titleSpacing, EdgeInsets? leadingPadding, Widget titleBuilder(String title)?, EdgeInsets? actionsPadding}) CkAppBarConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited