extractors property
Non-generic extractors for tokens, profile, verification tokens, and messages. Profile parsing is handled here via CkAuthExtractors.profile.
Implementation
final CkAuthExtractors extractors;
Non-generic extractors for tokens, profile, verification tokens, and messages. Profile parsing is handled here via CkAuthExtractors.profile.
final CkAuthExtractors extractors;