LoginCallback class

Constructors

LoginCallback({String? account, @Deprecated('Use account instead. Will be removed in v2.0.0.') String? username, String? password, Map<String, dynamic>? args, CkOtpTrigger? trigger})

Properties

account String
final
args Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
password String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trigger CkOtpTrigger?
final
username String
Deprecated getter for backward compatibility.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited