CkAuthEndpoints class

Constructors

CkAuthEndpoints({required String signup, required String signin, required String forgotPassword, required String sendOtp, required String verifyOtp, String? verifyForgetOtp, required String getProfile, required String updateProfile, required String logout, required String resetPassword, RequestMethod signupMethod = RequestMethod.POST, RequestMethod signinMethod = RequestMethod.POST, RequestMethod forgotPasswordMethod = RequestMethod.POST, RequestMethod sendOtpMethod = RequestMethod.POST, RequestMethod verifyOtpMethod = RequestMethod.POST, RequestMethod getProfileMethod = RequestMethod.GET, RequestMethod updateProfileMethod = RequestMethod.PATCH, RequestMethod logoutMethod = RequestMethod.POST, RequestMethod resetPasswordMethod = RequestMethod.POST, RequestMethod verifyForgotOtpMethod = RequestMethod.POST})
const

Properties

forgotPassword String
final
forgotPasswordMethod RequestMethod
final
getProfile String
final
getProfileMethod RequestMethod
final
hashCode int
The hash code for this object.
no setterinherited
logout String
final
logoutMethod RequestMethod
final
resetPassword String
final
resetPasswordMethod RequestMethod
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendOtp String
final
sendOtpMethod RequestMethod
final
signin String
final
signinMethod RequestMethod
final
signup String
final
signupMethod RequestMethod
final
updateProfile String
final
updateProfileMethod RequestMethod
final
verifyForgetOtp String?
final
verifyForgotOtpMethod RequestMethod
final
verifyOtp String
final
verifyOtpMethod RequestMethod
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited