CkAuthFlowHandlers class

Developer provides callbacks — CoreKit triggers them automatically. Completely avoids forcing any navigation system on the developer.

Constructors

CkAuthFlowHandlers({required void onAuthenticated(), required void showLogin(), void showOtpVerification()?, void showOnboarding()?, void showResetPassword()?, bool firstTimeOnly = true})
const

Properties

firstTimeOnly bool
When true (default), showOnboarding is only called for first-time users. When false, showOnboarding is called for all unauthenticated users.
final
hashCode int
The hash code for this object.
no setterinherited
onAuthenticated → void Function()
Custom callback to trigger when user is authenticated (e.g. show home screen or main UI)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLogin → void Function()
Custom callback to show login screen / dialog
final
showOnboarding → void Function()?
Custom callback to show onboarding screen / dialog (optional)
final
showOtpVerification → void Function()?
Custom callback to show OTP verification screen / dialog (optional)
final
showResetPassword → void Function()?
Custom callback to show reset password screen / dialog (optional)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited