CkAuthResult<T> class

Result wrapper for CkAuthService operations (sign-in, OTP, profile, social).

Constructors

CkAuthResult({required bool isSuccess, T? data, String? message, int? statusCode, bool requiresOtp = false, CkOtpTrigger? otpTrigger, dynamic rawResponse})
const
CkAuthResult.failure({String? message, int? statusCode, dynamic rawResponse})
const
CkAuthResult.success({T? data, String? message, int? statusCode, dynamic rawResponse})
const

Properties

data → T?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
final
message String?
final
otpTrigger CkOtpTrigger?
final
rawResponse → dynamic
final
requiresOtp bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited