CkLogoutHandler class

Constructors

CkLogoutHandler({required CkAuthTokenManager tokenManager, required CkProfileExtractor profileExtractor, required CkOtpFlowManager otpManager, required CkAuthStateController stateController, CkAuthFlowHandlers? handlers, String? logoutUrl, RequestMethod logoutMethod = RequestMethod.POST})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

autoNavigate() Future<void>
Perform automatic navigation based on route configuration
execute() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited