CkAppleAuthConfig class

Apple Sign-In configuration

Constructors

CkAppleAuthConfig({required String backendUrl, RequestMethod method = RequestMethod.POST, List<String> scopes = const ['email', 'fullName'], required Map<String, dynamic> bodyBuilder(CkAppleAuthData data), CkAuthExtractors? responseExtractors})
const

Properties

backendUrl String
final
bodyBuilder Map<String, dynamic> Function(CkAppleAuthData data)
final
hashCode int
The hash code for this object.
no setterinherited
method RequestMethod
final
responseExtractors CkAuthExtractors?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited