CkAppleAuthData class
Constructors
- CkAppleAuthData({String? identityToken, String? authorizationCode, String? email, String? fullName})
-
const
Properties
-
final
- email → String?
-
final
- fullName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- identityToken → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited