CkCustomSocialAuthConfig class

For any OAuth/social provider not covered by built-in ones

Constructors

CkCustomSocialAuthConfig({required String providerName, required String backendUrl, required Future<Map<String, dynamic>> authenticate(), required Map<String, dynamic> bodyBuilder(Map<String, dynamic> authData), RequestMethod method = RequestMethod.POST, CkAuthExtractors? responseExtractors})
const

Properties

authenticate Future<Map<String, dynamic>> Function()
Developer handles the entire social SDK flow and returns token/data
final
backendUrl String
final
bodyBuilder Map<String, dynamic> Function(Map<String, dynamic> authData)
Build body to send to backend
final
hashCode int
The hash code for this object.
no setterinherited
method RequestMethod
final
providerName String
final
responseExtractors CkAuthExtractors?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited