CkFacebookAuthConfig class

Facebook Sign-In configuration

Constructors

CkFacebookAuthConfig({required String backendUrl, RequestMethod method = RequestMethod.POST, List<String> permissions = const ['email', 'public_profile'], required Map<String, dynamic> bodyBuilder(CkFacebookAuthData data), CkAuthExtractors? responseExtractors})
const

Properties

backendUrl String
final
bodyBuilder Map<String, dynamic> Function(CkFacebookAuthData data)
final
hashCode int
The hash code for this object.
no setterinherited
method RequestMethod
final
permissions List<String>
final
responseExtractors CkAuthExtractors?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited