CkGoogleAuthData class

Data received from Google after successful Google Sign-In

Constructors

CkGoogleAuthData({String? idToken, String? accessToken, String? email, String? displayName, String? photoUrl})
const

Properties

accessToken String?
final
displayName String?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
idToken String?
final
photoUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited