streamOf method
Get the loading stream for a specific operation type.
Implementation
CkBehaviorStream<bool> streamOf(CkAuthLoadingType type) => _streams[type]!;
Get the loading stream for a specific operation type.
CkBehaviorStream<bool> streamOf(CkAuthLoadingType type) => _streams[type]!;