CkAuthStateController class
Pure Dart stream-based auth state. New subscribers immediately receive the current state.
Constructors
Properties
- current → CkAuthStatus
-
Current status (synchronous)
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAuthenticated → bool
-
no setter
- isChecking → bool
-
no setter
- isUnauthenticated → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
status
→ CkBehaviorStream<
CkAuthStatus> -
Stream of auth status — replays last value to new subscribers
no setter
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAuthenticated(
) → void -
setUnauthenticated(
) → void -
setUnknown(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited