CkButton class

Inheritance
Available extensions

Constructors

CkButton({required String titleText, Key? key, VoidCallback? onTap, Color? titleColor, Color? buttonColor, double? titleSize, double? buttonRadius, MainAxisAlignment alignment = MainAxisAlignment.center, FontWeight? titleWeight, double? buttonHeight, double? borderWidth, bool isLoading = false, double? buttonWidth, Color? borderColor, Widget? prefix, Widget? suffix, double? elevation, Gradient? gradient, EdgeInsetsGeometry? padding, Gradient? titleGradient, double titleSpacing = 10})
const

Properties

alignment MainAxisAlignment
final
borderColor Color?
final
borderWidth double?
final
buttonColor Color?
final
buttonHeight double?
final
buttonRadius double?
final
buttonWidth double?
final
center Widget

Available on Widget, provided by the Alignments extension

no setter
elevation double?
final
end Widget

Available on Widget, provided by the Alignments extension

no setter
gradient Gradient?
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
onTap VoidCallback?
final
padding EdgeInsetsGeometry?
final
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
prefix Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
start Widget

Available on Widget, provided by the Alignments extension

no setter
suffix Widget?
final
titleColor Color?
final
titleGradient Gradient?
final
titleSize double?
final
titleSpacing double
final
titleText String
final
titleWeight FontWeight?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<CkButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

toAr(num width, num height) Widget

Available on Widget, provided by the WidgetAspectRatio extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited