CkRadioGroup class
A theme-aware radio group that accepts a Map of options where
- key: submitted value (what the form gets)
- value: label displayed to the user
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CkRadioGroup
- Available extensions
Constructors
-
CkRadioGroup({required Map<
String, String> options, Key? key, String? initialKey, ValueChanged<String> ? onChanged, Axis direction = Axis.horizontal, bool horizontalScrollable = true, double itemSpacing = 12.0, TextStyle? textStyle, EdgeInsets? padding, Color? selectedColor, Color? unSelectedColor, double iconSize = 22.0}) -
const
Properties
- center → Widget
-
Available on Widget, provided by the Alignments extension
no setter - direction → Axis
-
final
- end → Widget
-
Available on Widget, provided by the Alignments extension
no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalScrollable → bool
-
final
- iconSize → double
-
final
- initialKey → String?
-
final
- itemSpacing → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter -
onChanged
→ ValueChanged<
String> ? -
final
-
options
→ Map<
String, String> -
final
- padding → EdgeInsets?
-
final
- paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color?
-
final
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter - start → Widget
-
Available on Widget, provided by the Alignments extension
no setter - textStyle → TextStyle?
-
final
- unSelectedColor → Color?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CkRadioGroup> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toAr(
num width, num height) → Widget -
Available on Widget, provided by the WidgetAspectRatio extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited