CkStateDropDownItemProperty class

Inheritance

Constructors

CkStateDropDownItemProperty({required String stateName, String? abbreviation, required bool isSelected})

Properties

abbreviation String?
final
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
getter/setter pairinherited
item String
getter/setter pairinherited
key String
Full state name (for key compatibility)
no setter
name String
Full state name (e.g. 'California')
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateName String
final
value String
Returns abbreviation if non-null and not empty, otherwise state name.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited