composerMaximizedHeightFraction property
Fraction of the screen height used when the composer is maximized.
Implementation
final double composerMaximizedHeightFraction;
Fraction of the screen height used when the composer is maximized.
final double composerMaximizedHeightFraction;