sendButtonBuilder property
Builds the send button, given the tap handler to wire up. Defaults to a plain IconButton with Icons.send.
Implementation
final Widget Function(VoidCallback onTap)? sendButtonBuilder;
Builds the send button, given the tap handler to wire up. Defaults to a plain IconButton with Icons.send.
final Widget Function(VoidCallback onTap)? sendButtonBuilder;