AccessControlFlag enum

Keychain access control flags that define security conditions for accessing items. These flags can be combined to create complex access control policies.

Inheritance
Available extensions

Values

devicePasscode → const AccessControlFlag

Constraint to access an item with a passcode.

biometryAny → const AccessControlFlag

Constraint to access an item with biometrics (Touch ID/Face ID).

biometryCurrentSet → const AccessControlFlag

Constraint to access an item with the currently enrolled biometrics.

userPresence → const AccessControlFlag

Constraint to access an item with either biometry or passcode.

watch → const AccessControlFlag

Constraint to access an item with a paired watch.

or → const AccessControlFlag

Combine multiple constraints with an OR operation.

and → const AccessControlFlag

Combine multiple constraints with an AND operation.

applicationPassword → const AccessControlFlag

Use an application-provided password for encryption.

privateKeyUsage → const AccessControlFlag

Enable private key usage for signing operations.

Properties

displayName String

Available on Enum, provided by the EnumDisplayName extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AccessControlFlag>
A constant List of the values in this enum, in order of their declaration.