AndroidOptions class

Specific options for Android platform.

Inheritance
  • Object
  • Options
  • AndroidOptions

Constructors

AndroidOptions({bool resetOnError = true, bool migrateOnAlgorithmChange = true, bool migrateWithBackup = false, bool enforceBiometrics = false, KeyCipherAlgorithm keyCipherAlgorithm = KeyCipherAlgorithm.RSA_ECB_OAEPwithSHA_256andMGF1Padding, StorageCipherAlgorithm storageCipherAlgorithm = StorageCipherAlgorithm.AES_GCM_NoPadding, AndroidBiometricType biometricType = AndroidBiometricType.biometricOrDeviceCredential, bool requireBiometricConfirmation = true, String? preferencesKeyPrefix, String? storageNamespace, String? biometricPromptTitle, String? biometricPromptSubtitle, String? biometricPromptNegativeButton})
Standard secure storage using AES-GCM with RSA OAEP key wrapping.
const
AndroidOptions.biometric({bool resetOnError = true, bool migrateOnAlgorithmChange = true, bool migrateWithBackup = false, bool enforceBiometrics = false, AndroidBiometricType biometricType = AndroidBiometricType.biometricOrDeviceCredential, bool requireBiometricConfirmation = true, String? preferencesKeyPrefix, String? storageNamespace, String? biometricPromptTitle, String? biometricPromptSubtitle, String? biometricPromptNegativeButton})
Maximum security storage with optional biometric authentication.
const

Properties

biometricPromptNegativeButton String?
The label for the negative (cancel) button shown in the biometric prompt.
final
biometricPromptSubtitle String?
The subtitle shown in the biometric authentication prompt.
final
biometricPromptTitle String?
The title shown in the biometric authentication prompt.
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
A getter that retrieves the options as a map representation.
no setterinherited
preferencesKeyPrefix String?
The prefix for a shared preference key. The prefix is used to make sure the key is unique to your application. An underscore (_) is added to the end of the prefix automatically. If not provided, a default prefix will be used.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storageNamespace String?
Provides full namespace isolation for this storage instance.
final

Methods

copyWith({bool? resetOnError, bool? migrateOnAlgorithmChange, bool? migrateWithBackup, bool? enforceBiometrics, KeyCipherAlgorithm? keyCipherAlgorithm, StorageCipherAlgorithm? storageCipherAlgorithm, AndroidBiometricType? biometricType, bool? requireBiometricConfirmation, String? preferencesKeyPrefix, String? storageNamespace, String? biometricPromptTitle, String? biometricPromptSubtitle, String? biometricPromptNegativeButton}) AndroidOptions
Creates a copy of this AndroidOptions with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
Converts the options into a map representation.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultOptions → const AndroidOptions
Default Android options with standard secure configuration.