KeyCipherAlgorithm enum

Algorithm used to encrypt/wrap the secret key in Android KeyStore.

Inheritance
Available extensions

Values

RSA_ECB_PKCS1Padding → const KeyCipherAlgorithm

Legacy RSA/ECB/PKCS1Padding for backwards compatibility.

PKCS#1 v1.5 padding is vulnerable to padding-oracle attacks. Existing data will be automatically migrated to the default algorithm on first access when migrateOnAlgorithmChange is true (the default).

RSA_ECB_OAEPwithSHA_256andMGF1Padding → const KeyCipherAlgorithm

RSA/ECB/OAEPWithSHA-256AndMGF1Padding (default, API 23+).

AES_GCM_NoPadding → const KeyCipherAlgorithm

AES/GCM/NoPadding for KeyStore-based key wrapping (supports biometrics).

Properties

displayName String

Available on Enum, provided by the EnumDisplayName extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyCipherAlgorithm>
A constant List of the values in this enum, in order of their declaration.