CkImage class

Inheritance
Available extensions

Constructors

CkImage({required String src, Color? imageColor, double? height, double borderRadius = 0, double? width, double? size, BoxFit fill = BoxFit.cover, String? defaultImage, bool enableGrayscale = false, Key? key, BorderRadius? borderRadiusCustom, bool enableAspectRatio = false, double borderWidth = 0, double borderOffset = 0, Color borderColor = Colors.black12})
const

Properties

borderColor Color
final
borderOffset double
final
borderRadius double
final
borderRadiusCustom BorderRadius?
final
borderWidth double
final
center Widget

Available on Widget, provided by the Alignments extension

no setter
defaultImage String?
final
enableAspectRatio bool
final
enableGrayscale bool
final
end Widget

Available on Widget, provided by the Alignments extension

no setter
fill BoxFit
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
imageColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
marginZero Widget

Available on Widget, provided by the WidgetMarginX extension

no setter
paddingZero Widget

Available on Widget, provided by the WidgetPaddingX extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
sliverBox Widget

Available on Widget, provided by the WidgetSliverBoxX extension

no setter
src String
final
start Widget

Available on Widget, provided by the Alignments extension

no setter
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getBorderRadius() BorderRadius
getImage() Widget
getOuterBorderRadius() BorderRadius
marginAll(double margin) Widget

Available on Widget, provided by the WidgetMarginX extension

marginOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

marginSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetMarginX extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paddingAll(double padding) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

paddingSymmetric({double horizontal = 0.0, double vertical = 0.0}) Widget

Available on Widget, provided by the WidgetPaddingX extension

placeholder() Widget
toAr(num width, num height) Widget

Available on Widget, provided by the WidgetAspectRatio extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited