CoreKitConfigDefaults mixin
- Superclass constraints
- @Deprecated('Inheriting directly from CoreKitConfig is recommended, as CoreKitConfig now provides concrete default implementations.')
Properties
- appbarConfig → CkAppBarConfig?
-
no setteroverride
- authConfig → CkAuthConfig?
-
no setteroverride
- ckTransportConfig → CkTransportConfig
-
no setterinherited
- context → BuildContext
-
no setterinherited
- designSize → Size
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBaseUrl → String
-
no setterinherited
- inputConfig → CkInputConfig?
-
no setteroverride
- listLoaderConfig → CkListLoaderConfig?
-
no setteroverride
-
onInit
→ Future<
void> Function()? -
Custom asynchronous initialization tasks run during the splash delay.
no setteroverride
- passwordObscureIcon → PasswordObscureIcon?
-
no setteroverride
- permissionHandlerColors → PermissionHadlerColors?
-
no setteroverride
- permissionHelperConfig → CkPermissionHelperConfig?
-
no setteroverride
- preInitChild → Widget?
-
New: UI shown before CoreKit is ready
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snackBarConfig → CkSnackBarConfig?
-
no setteroverride
- splashDelayMs → int
-
Splash delay in milliseconds (default: 3000ms = 3 seconds)
Set to 0 to disable the enforced delay
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited