CkTokenProvider class

Bridges stored tokens to CkTransport. Created by CoreKit / CkAuthService — not configured in app code.

Constructors

CkTokenProvider({required Future<String>? accessToken(), required Future<String>? refreshToken(), required Future<void> updateTokens(dynamic data)})
CkTokenProvider.unauthenticated()
Used when CkAuthConfig is not set (no auth module).
factory

Properties

accessToken Future<String>? Function()
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
refreshToken Future<String>? Function()
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTokens Future<void> Function(dynamic data)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited