CkTransport class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CkTransport
no setter

Static Methods

init({required CkTransportConfig config, required CkTokenProvider tokenProvider}) Future<CkTransport>
Create and initialize CkTransport.
request<T>({required RequestInput input, required T? responseBuilder(dynamic data), int retryCount = 0, int maxRetry = 2, bool showMessage = false, bool debug = false, bool isRetry = false}) Future<CkResponse<T?>>
Performs an HTTP request using the initialized transport singleton.