DioRequestBuilder class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build<T>({required RequestInput input, required T? responseBuilder(dynamic data), required CancelToken cancelToken, required bool showMessage, required int retryCount, required int maxRetry}) Future<CkResponse<T?>>
init({required CkTokenProvider tokenProvider, required Dio dio, required CkResponseExtractor responseExtractor}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance DioRequestBuilder
final