RequestInput class

Constructors

RequestInput({required String endpoint, required RequestMethod method, List<String>? pathParams, Map<String, dynamic>? queryParams, Map<String, String>? headers, Map<String, dynamic>? formFields, Map<String, dynamic>? jsonBody, Map<String, dynamic>? files, Duration? timeout, dynamic onSendProgress(int, int)?, dynamic onReceiveProgress(int, int)?, bool requiresToken = true, CancelToken? cancelToken, List<Map<String, dynamic>>? listBody})

Properties

cancelToken CancelToken?
final
endpoint String
final
files Map<String, dynamic>?
final
formFields Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
jsonBody Map<String, dynamic>?
final
listBody List<Map<String, dynamic>>?
final
method RequestMethod
final
onReceiveProgress → dynamic Function(int, int)?
final
onSendProgress → dynamic Function(int, int)?
final
pathParams List<String>?
final
queryParams Map<String, dynamic>?
final
requiresToken bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited