CkText class
- Inheritance
- Available extensions
Constructors
- CkText({required String text, Key? key, int? maxLines, TextAlign textAlign = TextAlign.center, double left = 0, double right = 0, double top = 0, double bottom = 0, double? fontSize, FontWeight? fontWeight, Color? textColor, TextStyle? style, TextOverflow? overflow, bool? enableBorder = false, Color? borderColor, double? borderRadious, Color? backgroundColor, MainAxisAlignment? alignment, BorderRadius? borderRadiusOnly, Widget? suffix, Widget? preffix, bool isDescription = false, double? textHeight, bool autoResize = true, double minFontSize = 10, double? maxAutoFontSize, double stepGranularity = 0.5, bool? softWrap, Color? decorationColor, TextDecoration? decoration, TextDirection? textDirection, double? height, double textSpacing = 10, double textScaleFactor = .9, bool preventScaling = false, Gradient? gradient})
-
const
Properties
- alignment → MainAxisAlignment?
-
final
- autoResize → bool
-
final
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadious → double?
-
final
- borderRadiusOnly → BorderRadius?
-
final
- bottom → double
-
final
- center → Widget
-
Available on Widget, provided by the Alignments extension
no setter - decoration → TextDecoration?
-
final
- decorationColor → Color?
-
final
- enableBorder → bool?
-
final
- end → Widget
-
Available on Widget, provided by the Alignments extension
no setter - fontSize → double?
-
final
- fontWeight → FontWeight?
-
final
- gradient → Gradient?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- isDescription → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- left → double
-
final
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter - maxAutoFontSize → double?
-
final
- maxLines → int?
-
final
- minFontSize → double
-
final
- overflow → TextOverflow?
-
final
- paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - preffix → Widget?
-
final
- preventScaling → bool
-
final
- right → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter - softWrap → bool?
-
final
- start → Widget
-
Available on Widget, provided by the Alignments extension
no setter - stepGranularity → double
-
final
- style → TextStyle?
-
final
- suffix → Widget?
-
final
- text → String
-
final
- textAlign → TextAlign
-
final
- textColor → Color?
-
final
- textDirection → TextDirection?
-
final
- textHeight → double?
-
final
- textScaleFactor → double
-
final
- textSpacing → double
-
final
- top → double
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
getStyle(
) → TextStyle -
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toAr(
num width, num height) → Widget -
Available on Widget, provided by the WidgetAspectRatio extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited