incrementMs property

int incrementMs
final

Extra milliseconds added to the delay per keystroke since the last fire. Grows the delay while the user is typing continuously (fast typers get a longer grace window). Default: 100ms.

Implementation

final int incrementMs;