onSearch property
Debounced callback — fires only when the user pauses typing AND the text has actually changed since the last fired value.
Implementation
final Function(String value)? onSearch;
Debounced callback — fires only when the user pauses typing AND the text has actually changed since the last fired value.
final Function(String value)? onSearch;