showClearButton property
Shows a x clear button when the field is non-empty. Suppressed if suffixIcon or suffixBuilder is provided.
Implementation
final bool showClearButton;
Shows a x clear button when the field is non-empty. Suppressed if suffixIcon or suffixBuilder is provided.
final bool showClearButton;