CkLogger class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

enableColors bool
getter/setter pair
enableLogs bool
getter/setter pair

Static Methods

apiDebug(String message, {String? tag}) → void
apiError(String message, {String? tag}) → void
debug(String message, {String? tag}) → void
error(String message, {String? tag}) → void
info(String message, {String? tag}) → void
screen(String message, {String? tag}) → void
warning(String message, {String? tag}) → void