CkPathProvider class

Web-safe wrapper for path_provider paths.

On web (and other unsupported platforms), calling these methods returns a functional in-memory virtual directory instead of throwing UnsupportedError or platform channel crashes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getApplicationDocumentsDirectory() Future<Directory>
Path to the directory where the application may place data that is user-generated.
getApplicationSupportDirectory() Future<Directory>
Path to the directory where the application may place application support files.
getDownloadsDirectory() Future<Directory>
Path to the directory where the user's downloaded files are stored.
getTemporaryDirectory() Future<Directory>
Path to the directory where the application may place temporary files.