CkPermissionExtension extension

Extension on Permission to provide easy access to .ensure().

on

Properties

toCkPermission CkPermission

Available on Permission, provided by the CkPermissionExtension extension

Wraps this Permission in a CkPermission.
no setter

Methods

ensure({bool showDialog = true, BuildContext? context}) Future<bool>

Available on Permission, provided by the CkPermissionExtension extension

Checks if the permission is granted, requests if needed, and shows settings dialog if permanently denied.