CkPermissionHandler class
Legacy permission handler wrapper kept for backward compatibility.
Please use CkPermission or Permission.ensure() for modern usage:
final status = await CkPermission.camera.ensure();
// or
final status = await Permission.camera.ensure();
- Annotations
-
- @Deprecated('Use CkPermission or Permission.ensure() extension instead. Example: CkPermission.camera.ensure() or Permission.camera.ensure()')
Constructors
- CkPermissionHandler({required Permission permission})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- permission → Permission
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getStatus(
) → Future< bool> - Checks and requests the permission.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited