CkPermissionHelper class

A helper class for handling permission requests.

For a more modern syntax, use CkPermission or Permission.ensure(), e.g.:

final status = await CkPermission.camera.ensure();
// or
final status = await Permission.camera.ensure();
Annotations
  • @Deprecated('Use CkPermission. Example: CkPermission.camera.ensure()')

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

request(Permission permission, {bool showDialog = true, BuildContext? context}) Future<bool>
Requests permission using CkPermission.ensure.
showDialog(Permission permission, {BuildContext? context}) Future
Displays the permission dialog for permanently denied permissions.