CkPermissionHelperConfig class

Constructors

CkPermissionHelperConfig({String permissionDenied = 'Permission Denied', String openSettings = 'Open Settings', String cancel = 'Cancel', String permissionIsPermanentlyDenied = 'Permission is permanently denied.', String toFixThisPleaseGoTo = 'To fix this, please go to ', String andAllowThePermissionManually = 'and allow the permission manually.'})
const

Properties

andAllowThePermissionManually String
final
cancel String
final
hashCode int
The hash code for this object.
no setterinherited
openSettings String
final
permissionDenied String
final
permissionIsPermanentlyDenied String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toFixThisPleaseGoTo String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited