CkUtils class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- deviceSize ↔ Size
-
getter/setter pair
Static Methods
-
divider(
) → RepaintBoundary -
formatDateTime(
DateTime dateTime) → String -
formatDateTimeToHms(
DateTime dateTime) → String -
formatDateTimeWithSHortMonth(
DateTime dateTime) → String -
formatDateToShortMonth(
DateTime dateTime) → String -
formatDouble(
double value) → String -
formatDurationToHms(
Duration duration) → String -
formatTime(
DateTime time) → String -
parseDate(
String? dateString) → DateTime? -
subtractYears(
DateTime date, int yearsToSubtract) → DateTime