NullableTimeOfDayParser extension
- on
Methods
-
tryToTimeOfDay(
BuildContext context) → TimeOfDay? -
Available on String?, provided by the NullableTimeOfDayParser extension
Safe version that returns null if string is null or invalid
Available on String?, provided by the NullableTimeOfDayParser extension
Safe version that returns null if string is null or invalid