CkLoginRequest class
Request configuration payload returned by loginRequestBuilder.
Supports all HTTP transport parameters (JSON body, form fields, files, path/query params).
Constructors
-
CkLoginRequest({Map<
String, dynamic> ? body, List<String> ? pathParams, Map<String, dynamic> ? queryParams, Map<String, dynamic> ? formFields, List<Map< ? listBody, Map<String, dynamic> >String, dynamic> ? files, Map<String, String> ? headers}) -
const
-
CkLoginRequest.fromBody(Map<
String, dynamic> body) -
Wrap a simple body map into CkLoginRequest for backward compatibility.
factory
Properties
-
body
→ Map<
String, dynamic> ? -
final
-
files
→ Map<
String, dynamic> ? -
final
-
formFields
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
final
-
listBody
→ List<
Map< ?String, dynamic> > -
final
-
pathParams
→ List<
String> ? -
final
-
queryParams
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Map< String, dynamic> ? body, List<String> ? pathParams, Map<String, dynamic> ? queryParams, Map<String, dynamic> ? formFields, List<Map< ? listBody, Map<String, dynamic> >String, dynamic> ? files, Map<String, String> ? headers}) → CkLoginRequest - Creates a copy of this CkLoginRequest with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited