CkAuthNetworkBootstrap class
Token layer prepared before CkTransport.init (CoreKit internal).
Constructors
- CkAuthNetworkBootstrap({required CkAuthTokenManager tokenManager, required CkTokenProvider tokenProvider})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenManager → CkAuthTokenManager
-
final
- tokenProvider → CkTokenProvider
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited