CkSocialAuthManager<TProfile> class
Manages social login flows on the backend. Designed to be 100% compile-safe with zero plugin-side SDK dependencies. Developer obtains social auth credentials on project-side and passes them here.
Constructors
-
CkSocialAuthManager({CkSocialLoginConfig? config, required CkAuthTokenManager tokenManager, required CkProfileExtractor<
TProfile> profileExtractor, required CkAuthStateController stateController, required CkLogoutHandler logoutHandler, required CkAuthExtractors defaultExtractors})
Properties
-
availableProviders
→ List<
CkSocialProvider> -
Get list of configured social providers
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticateApple(
CkAppleAuthData data) → Future< CkAuthResult< TProfile> > - Authenticate Apple credentials on backend
-
authenticateCustom(
{required String providerName, required Map< String, dynamic> authData}) → Future<CkAuthResult< TProfile> > - Authenticate custom OAuth credentials on backend
-
authenticateFacebook(
CkFacebookAuthData data) → Future< CkAuthResult< TProfile> > - Authenticate Facebook credentials on backend
-
authenticateGoogle(
CkGoogleAuthData data) → Future< CkAuthResult< TProfile> > - Authenticate Google credentials on backend
-
isProviderAvailable(
CkSocialProvider provider) → bool - Check if a specific provider is configured
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited