CkListLoaderConfig class
Global configuration for list/grid loader widgets. Allows customizing the default loading indicator and "no more data" widget both globally (via CoreKitConfig) and per-instance.
Constructors
- CkListLoaderConfig({Widget loaderWidget = const Padding(padding: EdgeInsets.all(20), child: Center(child: CircularProgressIndicator())), Widget noMoreDataWidget = const Padding(padding: EdgeInsets.all(20), child: Center(child: Text('No more data', style: TextStyle(color: Colors.grey))))})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- loaderWidget → Widget
-
Widget shown when loading more items (pagination footer).
final
- noMoreDataWidget → Widget
-
Widget shown when all pages have been loaded.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Widget? loaderWidget, Widget? noMoreDataWidget}) → CkListLoaderConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited