CoreKitConfig class abstract
Abstract configuration class that every app must extend to initialise CoreKit.
Override the required getters (imageBaseUrl and ckTransportConfig) and optionally override other properties.
Example:
class AppConfig extends CoreKitConfig {
@override
String get imageBaseUrl => 'https://cdn.example.com/';
@override
CkTransportConfig get ckTransportConfig => CkTransportConfig(
baseUrl: 'https://api.example.com',
refreshTokenEndpoint: '/auth/refresh',
);
}
Default Values
CoreKitConfig provides the following default values for optional getters:
- designSize =
Size(428, 926) - authConfig =
null - appbarConfig =
null - listLoaderConfig =
null - inputConfig =
null - snackBarConfig =
null - permissionHelperConfig =
null - permissionHandlerColors =
null - passwordObscureIcon =
null - preInitChild =
null - onInit =
null - splashDelayMs =
3000(3 seconds)
- Implementers
Constructors
Properties
- appbarConfig → CkAppBarConfig?
-
no setter
- authConfig → CkAuthConfig?
-
no setter
- ckTransportConfig → CkTransportConfig
-
no setter
- context → BuildContext
-
no setter
- designSize → Size
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageBaseUrl → String
-
no setter
- inputConfig → CkInputConfig?
-
no setter
- listLoaderConfig → CkListLoaderConfig?
-
no setter
-
onInit
→ Future<
void> Function()? -
Custom asynchronous initialization tasks run during the splash delay.
no setter
- passwordObscureIcon → PasswordObscureIcon?
-
no setter
- permissionHandlerColors → PermissionHadlerColors?
-
no setter
- permissionHelperConfig → CkPermissionHelperConfig?
-
no setter
- preInitChild → Widget?
-
New: UI shown before CoreKit is ready
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snackBarConfig → CkSnackBarConfig?
-
no setter
- splashDelayMs → int
-
Splash delay in milliseconds (default: 3000ms = 3 seconds)
Set to 0 to disable the enforced delay
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited