PasswordObscureIcon class
Configures the password visibility toggle icons shown in text fields.
Pass a custom instance via CoreKitConfig.passwordObscureIcon.
Constructors
- PasswordObscureIcon({required Widget show, required Widget hide, EdgeInsetsGeometry padding = const EdgeInsetsDirectional.only(end: 10)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hide → Widget
-
final
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show → Widget
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited