PermissionHadlerColors class
Colours used by the permission request UI overlay.
Constructors
- PermissionHadlerColors({required Color errorColor, required Color actionColor, required Color normalColor})
Properties
- actionColor → Color
-
final
- errorColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- normalColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited