CkAlert class
Constructors
- CkAlert({required String title, required Function onTap, Widget? content, bool disableActionButton = false, bool disableCancelButton = false, String? actionButtonTittle, String? cancelButtonTittle, Color? cancelButtonColor, Color? actionButtonColor, Color? actionTitleColor, Color? cancelTitleColor})
Properties
- actionButtonColor → Color?
-
final
- actionButtonTittle ↔ String?
-
getter/setter pair
- actionTitleColor → Color?
-
final
- cancelButtonColor → Color?
-
final
- cancelButtonTittle ↔ String?
-
getter/setter pair
- cancelTitleColor → Color?
-
final
- content → Widget?
-
final
- disableActionButton → bool
-
final
- disableCancelButton → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTap → Function
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited