CkScreenshotPreview class
Constructors
- CkScreenshotPreview({required BuildContext buildContext, required String imagePath, Duration duration = const Duration(seconds: 3), double width = 120, double height = 80, double bottom = 20, double left = 20, Color borderColor = Colors.white, double borderRadius = 8, double borderWidth = 2, BoxShadow? boxShadow})
Properties
- borderColor → Color
-
final
- borderRadius → double
-
final
- borderWidth → double
-
final
- bottom → double
-
final
- boxShadow → BoxShadow
-
final
- buildContext → BuildContext
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- imagePath → String
-
final
- left → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
final
Methods
-
hide(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
show(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited