CkSnackBarConfig class
Global configuration for the CkSnackBar custom overlay widget.
Allows configuring styles, borders, shadows, layout metrics, semantic colors, and icons globally.
Constructors
-
CkSnackBarConfig({CkSnackBarPosition? position, double? borderRadius, Color? backgroundColor, List<
BoxShadow> ? boxShadow, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? borderWidthLeft, double? borderWidthOthers, double? iconSize, Color? successColor, Color? errorColor, Color? warningColor, Color? infoColor, IconData? successIcon, IconData? errorIcon, IconData? warningIcon, IconData? infoIcon}) -
const
Properties
- backgroundColor → Color?
-
The fill/background color of the snackbar container.
final
- borderRadius → double?
-
The corner radius for the snackbar container.
final
- borderWidthLeft → double?
-
Left-side accent indicator border width.
final
- borderWidthOthers → double?
-
Border width for top, right, and bottom sides.
final
-
boxShadow
→ List<
BoxShadow> ? -
Custom shadow effect applied to the snackbar.
final
- errorColor → Color?
-
Color override when type is CkSnackBarType.error.
final
- errorIcon → IconData?
-
Icon override when type is CkSnackBarType.error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconSize → double?
-
Size of the semantic status icon.
final
- infoColor → Color?
-
Color override when type is CkSnackBarType.info.
final
- infoIcon → IconData?
-
Icon override when type is CkSnackBarType.info.
final
- margin → EdgeInsetsGeometry?
-
Outer padding/margin surrounding the snackbar.
final
- padding → EdgeInsetsGeometry?
-
Inner padding inside the snackbar borders.
final
- position → CkSnackBarPosition?
-
The screen position of the snackbar (top or bottom). Defaults to CkSnackBarPosition.bottom.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successColor → Color?
-
Color override when type is CkSnackBarType.success.
final
- successIcon → IconData?
-
Icon override when type is CkSnackBarType.success.
final
- textStyle → TextStyle?
-
Text style applied to the snackbar text description.
final
- warningColor → Color?
-
Color override when type is CkSnackBarType.warning.
final
- warningIcon → IconData?
-
Icon override when type is CkSnackBarType.warning.
final
Methods
-
copyWith(
{CkSnackBarPosition? position, double? borderRadius, Color? backgroundColor, List< BoxShadow> ? boxShadow, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, TextStyle? textStyle, double? borderWidthLeft, double? borderWidthOthers, double? iconSize, Color? successColor, Color? errorColor, Color? warningColor, Color? infoColor, IconData? successIcon, IconData? errorIcon, IconData? warningIcon, IconData? infoIcon}) → CkSnackBarConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited