CkMultilineTextField class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- CkMultilineTextField
- Available extensions
Constructors
- CkMultilineTextField({required CkValidationType validationType, Key? key, String? hintText, String? labelText, Widget? prefixIcon, TextEditingController? controller, String? prefixText, double borderRadius = 12, dynamic onSaved(String value, TextEditingController controller)?, dynamic onChanged(String value)?, Color? borderColor, VoidCallback? onTap, Widget? suffixIcon, bool isReadOnly = false, String onInitalize(TextEditingController controller)?, bool showActionButton = false, Widget? actionButtonIcon, String originalPassword()?, String? validation(String? value)?, Color? backgroundColor, double? borderWidth, bool showValidationMessage = true, TextAlign textAlign = TextAlign.left, bool enableHtml = false, double height = 150, double? minHeight, bool isDense = false, int? maxLength, int? maxWords, int minLength = 0, TextStyle? counterTextStyle, int minWords = 0, TextStyle? hintStyle, CkMultilineHintLimitBuilder? multilineLimitHintBuilder, dynamic onFocusChanged(FocusNode focusNode)?, TextStyle? textStyle, double? fontSize, EdgeInsetsGeometry? contentPadding, bool expand = true, bool enableMaximize = true, double? maximizedHeight, bool enableCapitalization = true})
-
const
Properties
- actionButtonIcon → Widget?
-
final
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → double
-
final
- borderWidth → double?
-
final
- center → Widget
-
Available on Widget, provided by the Alignments extension
no setter - contentPadding → EdgeInsetsGeometry?
-
final
- controller → TextEditingController?
-
final
- counterTextStyle → TextStyle?
-
final
- enableCapitalization → bool
-
final
- enableHtml → bool
-
final
- enableMaximize → bool
-
final
- end → Widget
-
Available on Widget, provided by the Alignments extension
no setter - expand → bool
-
final
- fontSize → double?
-
final
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- hintStyle → TextStyle?
-
final
- hintText → String?
-
final
- isDense → bool
-
final
- isReadOnly → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
- marginZero → Widget
-
Available on Widget, provided by the WidgetMarginX extension
no setter - maximizedHeight → double?
-
final
- maxLength → int?
-
final
- maxWords → int?
-
final
- minHeight → double?
-
final
- minLength → int
-
final
- minWords → int
-
final
- multilineLimitHintBuilder → CkMultilineHintLimitBuilder?
-
final
- onChanged → dynamic Function(String value)?
-
final
- onFocusChanged → dynamic Function(FocusNode focusNode)?
-
final
- onInitalize → String Function(TextEditingController controller)?
-
final
- onSaved → dynamic Function(String value, TextEditingController controller)?
-
final
- onTap → VoidCallback?
-
final
- originalPassword → String Function()?
-
final
- paddingZero → Widget
-
Available on Widget, provided by the WidgetPaddingX extension
no setter - prefixIcon → Widget?
-
final
- prefixText → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showActionButton → bool
-
final
- showValidationMessage → bool
-
final
- sliverBox → Widget
-
Available on Widget, provided by the WidgetSliverBoxX extension
no setter - start → Widget
-
Available on Widget, provided by the Alignments extension
no setter - suffixIcon → Widget?
-
final
- textAlign → TextAlign
-
final
- textStyle → TextStyle?
-
final
- validation → String? Function(String? value)?
-
final
- validationType → CkValidationType
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< CkMultilineTextField> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
marginAll(
double margin) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
marginSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetMarginX extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paddingAll(
double padding) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingOnly(
{double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
paddingSymmetric(
{double horizontal = 0.0, double vertical = 0.0}) → Widget -
Available on Widget, provided by the WidgetPaddingX extension
-
toAr(
num width, num height) → Widget -
Available on Widget, provided by the WidgetAspectRatio extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited