getApplicationDocumentsDirectory static method
Path to a directory where the application may place data that is user-generated, or that cannot otherwise be recreated by your application.
Implementation
static Future<Directory> getApplicationDocumentsDirectory() =>
pp.getApplicationDocumentsDirectory();